@@ -15,7 +15,9 @@
          read(11, '(a)') configFile
          close( 11 )
       endif
-
+!!!!!
+      write(0,*) ' configfile = ',  configFile
+!!!!!!!!!!!      
       call epRdNewConfFile
       call cerrorMsg(' ', 1)
       call cerrorMsg(' ', 1)
@@ -58,7 +60,9 @@
 #include "Zcnfig.h"
 #include "ZepDraw.h"
       integer sum1, i, sum2,  levelmx
-
+!!!!!!!
+      write(0,*) ' entering fixconfig'
+!!!!!!!      
       call epfixConfig
       call epMemoCnfgFile   ! next one is here bef. 9.15
       call epReadConfig
