@@ -6,23 +6,23 @@
       real*8  z ! input. matter z.
       real*8  teta ! output. sampled angle of photons relative to
                    !       the inciedent electron
-      real*8 d, pi, hpi, maxu, u
+      real*8 d, pi,  maxu, u
       real*8 a/0.625d0/
 
       
 !
-      parameter( pi=3.14159265d0, hpi= pi/2)
+      parameter( pi=3.14159265d0)
 
       d = 0.13d0*(0.8d0 + 1.3d0/z)*
      *         (100.d0+ 1.d0/e) * (1.+ eg/e)
 
 !
-      maxu = e*hpi/m
-      do while (.true.)
+      maxu = e*pi/m
+      do 
          call epPBAng(a, d, u)
-         if(u .lt. maxu) goto 10
+         if(u .lt. maxu) exit
       enddo
- 10   continue
+
 !
       teta = u*m/e
       end
@@ -34,8 +34,8 @@
 !        one.
 !        The angular distribution is approximated as
 !      {  uexp(-au) + duexp(-3au) } du
-!        where a = 0.625 and d=27.0. This is  employed in
-!        GEANT.
+!        where a = 0.625 and d=27.0. 
+!        old geant4 type
       real*8 e ! input. energy of e+/e_ (smaller energy)
       real*8 m ! input. mass of the electron. must be in the same unit as
                !         e
@@ -45,7 +45,8 @@
       real*8 a/0.625d0/, d/27.0d0/, pi, hpi, maxu, u
       parameter( pi=3.14159265d0, hpi= pi/2)
 !
-      maxu = e*hpi/m
+!      maxu = e*hpi/m
+      maxu = e*pi/m   ! 2018,Apr.3
       do while (.true.)
          call epPBAng(a, d, u)
          if(u .lt. maxu) goto 10
